exceptiontools.TupletError
==========================

.. abjad-lineage:: abjad.tools.exceptiontools.TupletError.TupletError

.. autoclass:: abjad.tools.exceptiontools.TupletError.TupletError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__unicode__
   :noindex:
